
Imports DotNetNuke
Imports DotNetNuke.Common
Imports DotNetNuke.Entities.Modules
Imports System.Data.SqlClient

Namespace VinoCellar.Modules.VCLinks
    Partial Class ucViewAll
        Inherits Entities.Modules.PortalModuleBase

#Region " Private Members "
        Private strColumn As String
        Private strRow As String

        Private intTotalPages As Integer
        Private intLinkCount As Integer
        Private currentPageNumber As Integer = 1
        Private Page_Size As Integer = 20
        Private intSortID As Integer
        Private intCatID As Integer


#End Region

#Region " Private Methods "

        Private Sub Page_Load(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles MyBase.Load
            Try
                If Page.IsPostBack = False Then
                    intSortID = 1 'Default to Winery Links
                    'Check if user is anonymous, if so, no option for personalization of page_size
                    If Me.UserId = -1 Then
                        lblPageSize.Visible = "False"
                        ddlPageSize.Visible = "False"
                    Else
                        lblPageSize.Visible = "True"
                        ddlPageSize.Visible = "True"
                        'Get any personalization if user has it, for page size
                        If Not DotNetNuke.Services.Personalization.Personalization.GetProfile(ModuleId.ToString, "PageSize") Is Nothing Then
                            Page_Size = CType(DotNetNuke.Services.Personalization.Personalization.GetProfile(ModuleId.ToString, "PageSize"), Integer)
                            ddlPageSize.SelectedValue = Page_Size
                        End If
                    End If

                    ReadQueryString()
                    If intSortID > 0 Then
                        'category has a value so we need to populate page
                        lblCategory.Text = CStr(intSortID)
                        PopulateCategoryDataList()
                        PopulateGridview()
                    End If
                End If

                If PortalSecurity.IsInRole("Administrators") Or _
                PortalSecurity.IsInRole("VCLink Moderator") Then
                    lbEditCategories.Visible = "true"
                End If

            Catch exc As Exception
                ProcessModuleLoadException(Me, exc)
            End Try
        End Sub

        Private Sub ReadQueryString()
            If (Request("WineLinkCategory") <> "") Then
                If (IsNumeric(Request("WineLinkCategory"))) Then
                    intSortID = CInt(Request.QueryString("WineLinkCategory"))
                Else
                    intSortID = 1 'Which is the first category in the DB
                    'Perhaps make this a module setting for default category
                End If
            End If
            If (Request("Page") <> "") Then
                If (IsNumeric(Request("Page"))) Then
                    currentPageNumber = CInt(Request.QueryString("Page"))
                Else
                    currentPageNumber = 1
                End If
            End If
        End Sub

        Private Sub PopulateCategoryDataList()
            Try

                Dim strConn As String = ConfigurationManager.AppSettings("SiteSqlServer")
                Dim objConn As New SqlConnection(strConn)
                Dim cmd As New SqlCommand

                cmd.CommandText = "vcLinks_GetCategories_All"
                cmd.CommandType = CommandType.StoredProcedure

                cmd.Connection = objConn

                objConn.Open()

                dlCategories.DataSource = cmd.ExecuteReader
                dlCategories.DataBind()

                objConn.Close()

            Catch exc As Exception        'Module failed to load
                ProcessModuleLoadException(Me, exc)
            End Try
        End Sub

        Private Sub PopulateGridview()
            Try

                Dim strConn As String = ConfigurationManager.AppSettings("SiteSqlServer")
                Dim objConn As New SqlConnection(strConn)
                Dim cmd As New SqlCommand

                cmd.CommandText = "vcLinks_GetLinks_ByCategory"
                cmd.CommandType = CommandType.StoredProcedure

                cmd.Parameters.AddWithValue("@PageNumber", currentPageNumber)
                cmd.Parameters.AddWithValue("@PageSize", Page_Size)
                cmd.Parameters.AddWithValue("@SortID", intSortID)

                cmd.Connection = objConn

                objConn.Open()

                gvLinks.DataSource = cmd.ExecuteReader
                gvLinks.DataBind()

                objConn.Close()

                GetTotalLinkPages()

                'Dim totalRows As Double = CInt(cmd.Parameters("@totalRows").Value)
                intTotalPages = CInt(Math.Ceiling(intLinkCount / Page_Size))

                lblTotalPages.Text = intTotalPages.ToString
                lblCurrentPage.Text = currentPageNumber.ToString()

                If currentPageNumber = 1 Then
                    lbPrevious.Enabled = "False"
                    If (Int32.Parse(lblTotalPages.Text) > 1) Then
                        lbNext.Enabled = "True"
                    Else
                        lbNext.Enabled = "False"
                    End If
                Else
                    lbPrevious.Enabled = "True"

                    If (currentPageNumber = Int32.Parse(lblTotalPages.Text)) Then
                        lbNext.Enabled = "False"
                    Else
                        lbNext.Enabled = "True"
                    End If
                End If

                'Gridview is populated with a categoryID, but we need the category name
                'To populate the label
                PopulateLabel()

            Catch exc As Exception        'Module failed to load
                ProcessModuleLoadException(Me, exc)
            End Try
        End Sub

        Private Sub PopulateLabel()

            Dim strConn As String = ConfigurationManager.AppSettings("SiteSqlServer")
            Dim objConn As New SqlConnection(strConn)
            Dim cmd As New SqlCommand

            cmd.CommandText = "vcLinks_GetCategoryName"
            cmd.CommandType = CommandType.StoredProcedure

            cmd.Parameters.AddWithValue("@SortID", intSortID)

            cmd.Connection = objConn

            objConn.Open()

            lblCatname.Text = "<h3>" + cmd.ExecuteScalar + "</h3>"

            objConn.Close()


        End Sub

        Private Sub GetTotalLinkPages()

            'Count all records in vcRestaurant table
            'Then divide by PAGE_SIZE using math.ceiling
            Dim strConn As String = ConfigurationManager.AppSettings("SiteSqlServer")
            Dim objConn As New SqlConnection(strConn)
            Dim cmd As New SqlCommand

            cmd.CommandText = "vcLinks_GetTotalPages"
            cmd.CommandType = CommandType.StoredProcedure

            cmd.Parameters.AddWithValue("@SortID", intSortID)

            cmd.Connection = objConn

            objConn.Open()

            intLinkCount = cmd.ExecuteScalar

            objConn.Close()

        End Sub

        Private Sub AddCategory()

            Dim strConn As String = ConfigurationManager.AppSettings("SiteSqlServer")
            Dim objConn As New SqlConnection(strConn)
            Dim cmd As New SqlCommand

            cmd.CommandText = "vcLinksCategory_AddCategory"
            cmd.CommandType = CommandType.StoredProcedure

            cmd.Parameters.AddWithValue("@CategoryName", tbCategoryName.Text)
            cmd.Parameters.AddWithValue("@CategoryDesc", tbCategoryDesc.Text)

            cmd.Connection = objConn

            objConn.Open()

            cmd.ExecuteNonQuery()

            objConn.Close()

        End Sub

        Private Sub PopulateCategoryDropdown()
            Try

                'Populate ddlCategory

                ' get Country object
                Dim strConn As String = ConfigurationManager.AppSettings("SiteSqlServer")
                Dim objConn As New SqlConnection(strConn)
                Dim cmd As New SqlCommand

                cmd.CommandText = "vcLinksCategory_GetCategories_All"
                cmd.CommandType = CommandType.StoredProcedure
                cmd.Connection = objConn

                objConn.Open()

                ddlCategories.DataSource = cmd.ExecuteReader
                ddlCategories.DataTextField = "CategoryName"
                ddlCategories.DataValueField = "VCLinksCategoryID"
                ddlCategories.DataBind()

                objConn.Close()


            Catch exc As Exception        'Module failed to load
                ProcessModuleLoadException(Me, exc)
            End Try
        End Sub

        Private Sub DeleteCategory()

            'Open Connection
            Dim strConn As String = ConfigurationManager.AppSettings("SiteSqlServer")
            Dim objConn As New SqlConnection(strConn)
            Dim cmd As New SqlCommand

            cmd.CommandText = "vcLinks_DeleteCategory"
            cmd.CommandType = CommandType.StoredProcedure
            cmd.Connection = objConn

            'Declare Parameter(s)
            cmd.Parameters.AddWithValue("@intVCLinksCategoryID", ddlCategories.SelectedValue)

            objConn.Open()

            'Get ID of Restaurant Just added 
            cmd.ExecuteNonQuery()

            objConn.Close()

        End Sub

#End Region

#Region " Event Handlers "

        Protected Sub lbAddLink_Click(ByVal sender As Object, ByVal e As System.EventArgs) Handles lbAddLink.Click

            'Redirect to the "AddLink" control
            Dim objModules As Entities.Modules.ModuleController = New Entities.Modules.ModuleController
            Response.Redirect(Globals.NavigateURL(PortalSettings.ActiveTab.TabID, Null.NullString, "LinkID=0"))

        End Sub

        Protected Sub lbPrevious_Click(ByVal sender As Object, ByVal e As System.EventArgs) Handles lbPrevious.Click

            currentPageNumber = Int32.Parse(lblCurrentPage.Text) - 1
            intSortID = CInt(lblCategory.Text)
            Response.Redirect(Globals.NavigateURL(Me.TabId, Null.NullString, "WineLinkCategory=" & intSortID, "Page=" & currentPageNumber), True)

        End Sub

        Protected Sub lbNext_Click(ByVal sender As Object, ByVal e As System.EventArgs) Handles lbNext.Click

            currentPageNumber = Int32.Parse(lblCurrentPage.Text) + 1
            intSortID = CInt(lblCategory.Text)
            Response.Redirect(Globals.NavigateURL(Me.TabId, Null.NullString, "WineLinkCategory=" & intSortID, "Page=" & currentPageNumber), True)

        End Sub

        Protected Sub dlCategories_SelectedIndexChanged(ByVal sender As Object, ByVal e As System.EventArgs) Handles dlCategories.SelectedIndexChanged
            intSortID = dlCategories.SelectedValue
            Response.Redirect(Globals.NavigateURL(Me.TabId, Null.NullString, "WineLinkCategory=" & intSortID), True)
        End Sub

        Protected Sub ddlPageSize_SelectedIndexChanged(ByVal sender As Object, ByVal e As System.EventArgs) Handles ddlPageSize.SelectedIndexChanged

            Page_Size = ddlPageSize.SelectedValue
            DotNetNuke.Services.Personalization.Personalization.SetProfile(ModuleId.ToString, "PageSize", Page_Size)

            intSortID = CInt(lblCategory.Text)
            Response.Redirect(Globals.NavigateURL(Me.TabId, Null.NullString, "WineLinkCategory=" & intSortID), True)

        End Sub

        Protected Sub gvLinks_RowCommand(ByVal sender As Object, ByVal e As System.Web.UI.WebControls.GridViewCommandEventArgs) Handles gvLinks.RowCommand
            Dim strLinkID As String
            If e.CommandName = "GoToEditPage" Then
                strLinkID = gvLinks.DataKeys(Convert.ToInt32(e.CommandArgument)).Value.ToString()
                'do stuff with strLinkID 
                Dim objModules As Entities.Modules.ModuleController = New Entities.Modules.ModuleController
                Response.Redirect(Globals.NavigateURL(PortalSettings.ActiveTab.TabID, Null.NullString, "LinkDetail=" & strLinkID))
            End If
        End Sub

        Protected Sub lbEditCategories_Click(ByVal sender As Object, ByVal e As System.EventArgs) Handles lbEditCategories.Click

            pnlCategory.Visible = "True"
            PopulateCategoryDropdown()

        End Sub

        Protected Sub bCancel_Click(ByVal sender As Object, ByVal e As System.EventArgs) Handles bCancel.Click

            pnlCategory.Visible = "False"


        End Sub

        Protected Sub bAddCategory_Click(ByVal sender As Object, ByVal e As System.EventArgs) Handles bAddCategory.Click

            AddCategory()
            pnlCategory.Visible = "False"

        End Sub

        Protected Sub bDeleteCat_Click(ByVal sender As Object, ByVal e As System.EventArgs) Handles bDeleteCat.Click

            DeleteCategory()

        End Sub




#End Region


    End Class
End Namespace
